import * as sass from "sass";
import { eleventyImageTransformPlugin } from "@11ty/eleventy-img";
import { DateTime } from "luxon";

export default async function (eleventyConfig) {
	// Filters
	eleventyConfig.addFilter("dateLocale", function (value) {
		return DateTime.fromISO(new Date(value).toISOString()).toLocaleString({
			year: 'numeric',
			month: 'short',
			day: '2-digit',
		});
	});

	// SCSS
	eleventyConfig.addTemplateFormats("scss");

	eleventyConfig.addExtension("scss", {
		outputFileExtension: "css",
		compile: async function (inputContent) {
			let result = sass.compileString(inputContent);

			return async (data) => {
				return result.css;
			};
		}
	});

	//Images
	eleventyConfig.addPlugin(eleventyImageTransformPlugin);

	eleventyConfig.addPassthroughCopy("content/robots.txt");
}

export const config = {
	dir: {
		input: "content",
		includes: "includes",
		layouts: "layouts",
		output: "dist"
	}
};